__version__ = '1.4.0'
__date__ = '1 November 2025, 16:20 UTC+7'

version = '{} ({})'.format(__version__, __date__)
version_info = None